pub fn get_agent(storage_root: &Path, slug: &str) -> Option<AgentDefinition>Expand description
Fetch a single agent by slug, if present in the (possibly seeded) roster.
pub fn get_agent(storage_root: &Path, slug: &str) -> Option<AgentDefinition>Fetch a single agent by slug, if present in the (possibly seeded) roster.