pub fn can_relay_agent_outcome(
msg: &ChatMessage,
participants: &[ChatParticipant],
) -> boolExpand description
Whether a processed agent outcome may be relayed to group peers.
pub fn can_relay_agent_outcome(
msg: &ChatMessage,
participants: &[ChatParticipant],
) -> boolWhether a processed agent outcome may be relayed to group peers.