pub struct RendezvousHint {
pub kind: String,
pub value: String,
}Expand description
One rendezvous hint — where to try to reach the peer, tried in list order.
Fields
kind: String"domain" | "edge" | "nym" | "relay" | "libp2p" | "mailbox" | "mdns".
value: StringTrait Implementations
Sourceimpl Clone for RendezvousHint
impl Clone for RendezvousHint
Sourcefn clone(&self) -> RendezvousHint
fn clone(&self) -> RendezvousHint
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RendezvousHint
impl Debug for RendezvousHint
Sourceimpl<'de> Deserialize<'de> for RendezvousHint
impl<'de> Deserialize<'de> for RendezvousHint
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for RendezvousHint
impl PartialEq for RendezvousHint
Sourcefn eq(&self, other: &RendezvousHint) -> bool
fn eq(&self, other: &RendezvousHint) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for RendezvousHint
impl Serialize for RendezvousHint
impl Eq for RendezvousHint
impl StructuralPartialEq for RendezvousHint