pub struct FacetValue {
pub value: String,
pub label: String,
pub count: usize,
pub selected: bool,
}Expand description
One selectable value within a facet, with its count in the current result and whether it’s selected.
Fields
value: Stringlabel: Stringcount: usizeselected: boolTrait Implementations
Sourceimpl Clone for FacetValue
impl Clone for FacetValue
Sourcefn clone(&self) -> FacetValue
fn clone(&self) -> FacetValue
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FacetValue
impl Debug for FacetValue
Sourceimpl<'de> Deserialize<'de> for FacetValue
impl<'de> Deserialize<'de> for FacetValue
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for FacetValue
impl PartialEq for FacetValue
Sourcefn eq(&self, other: &FacetValue) -> bool
fn eq(&self, other: &FacetValue) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for FacetValue
impl Serialize for FacetValue
impl StructuralPartialEq for FacetValue