pub struct ChallengeResponse {
pub nonce: String,
pub responder_did: String,
pub responder_pubkey_hex: String,
pub signature_hex: String,
}Expand description
The responder’s answer, proving control of the key bound to responder_did.
responder_pubkey_hex is the 32-byte ed25519 public key (hex); signature_hex
is the 64-byte ed25519 signature (hex) over signed_message(nonce, responder_did).
Fields
nonce: Stringresponder_did: Stringresponder_pubkey_hex: Stringsignature_hex: StringTrait Implementations
Sourceimpl Clone for ChallengeResponse
impl Clone for ChallengeResponse
Sourcefn clone(&self) -> ChallengeResponse
fn clone(&self) -> ChallengeResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChallengeResponse
impl Debug for ChallengeResponse
Sourceimpl<'de> Deserialize<'de> for ChallengeResponse
impl<'de> Deserialize<'de> for ChallengeResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ChallengeResponse
impl PartialEq for ChallengeResponse
Sourcefn eq(&self, other: &ChallengeResponse) -> bool
fn eq(&self, other: &ChallengeResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ChallengeResponse
impl Serialize for ChallengeResponse
impl StructuralPartialEq for ChallengeResponse