#[repr(C)]pub struct CompiledCapability {
pub app_id_hash: u64,
pub clearance_level: u8,
pub domain_count: u8,
pub permitted_domains: [u64; 8],
}Expand description
Zero-allocation capability record used by the Sentinel during query execution.
Fields
app_id_hash: u64clearance_level: u8domain_count: u8permitted_domains: [u64; 8]Trait Implementations
Sourceimpl Clone for CompiledCapability
impl Clone for CompiledCapability
Sourcefn clone(&self) -> CompiledCapability
fn clone(&self) -> CompiledCapability
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CompiledCapability
impl Debug for CompiledCapability
Sourceimpl Default for CompiledCapability
impl Default for CompiledCapability
Sourceimpl PartialEq for CompiledCapability
impl PartialEq for CompiledCapability
Sourcefn eq(&self, other: &CompiledCapability) -> bool
fn eq(&self, other: &CompiledCapability) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for CompiledCapability
impl Eq for CompiledCapability
impl StructuralPartialEq for CompiledCapability