pub fn remote_mcp_probe(transport: &McpTransport) -> Result<usize, String>Expand description
Test an MCP endpoint without asking it to generate text. It sends the
standard tools/list request and only reports that a response was received.
pub fn remote_mcp_probe(transport: &McpTransport) -> Result<usize, String>Test an MCP endpoint without asking it to generate text. It sends the
standard tools/list request and only reports that a response was received.