pub fn find<'a>(peers: &'a [SocialPeer], did: &str) -> Option<&'a SocialPeer>Expand description
Find the peer with the given did, if present.
pub fn find<'a>(peers: &'a [SocialPeer], did: &str) -> Option<&'a SocialPeer>Find the peer with the given did, if present.