pub struct GuardianNotification {
pub guardian_did: String,
pub principal_did: String,
pub asset_uri: String,
pub flag_kind: String,
pub severity_level: u64,
pub detail: String,
pub time_unix: u64,
}Expand description
A notification to a guardian that a flagged asset was ingested for a principal under their guardianship.
Fields
guardian_did: Stringprincipal_did: Stringasset_uri: Stringflag_kind: Stringseverity_level: u640 Info · 1 Notice · 2 Concern · 3 Urgent.
detail: Stringtime_unix: u64Trait Implementations
Sourceimpl Clone for GuardianNotification
impl Clone for GuardianNotification
Sourcefn clone(&self) -> GuardianNotification
fn clone(&self) -> GuardianNotification
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GuardianNotification
impl Debug for GuardianNotification
Sourceimpl<'de> Deserialize<'de> for GuardianNotification
impl<'de> Deserialize<'de> for GuardianNotification
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for GuardianNotification
impl PartialEq for GuardianNotification
Sourcefn eq(&self, other: &GuardianNotification) -> bool
fn eq(&self, other: &GuardianNotification) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for GuardianNotification
impl Serialize for GuardianNotification
impl Eq for GuardianNotification
impl StructuralPartialEq for GuardianNotification