pub struct SanctuaryVaultNote {
pub id: String,
pub body: String,
pub created_at_unix: u32,
}Expand description
A sensitive note held only inside the encrypted vault.
Fields
id: Stringbody: Stringcreated_at_unix: u32Trait Implementations
Sourceimpl Clone for SanctuaryVaultNote
impl Clone for SanctuaryVaultNote
Sourcefn clone(&self) -> SanctuaryVaultNote
fn clone(&self) -> SanctuaryVaultNote
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SanctuaryVaultNote
impl Debug for SanctuaryVaultNote
Sourceimpl<'de> Deserialize<'de> for SanctuaryVaultNote
impl<'de> Deserialize<'de> for SanctuaryVaultNote
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for SanctuaryVaultNote
impl PartialEq for SanctuaryVaultNote
Sourcefn eq(&self, other: &SanctuaryVaultNote) -> bool
fn eq(&self, other: &SanctuaryVaultNote) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for SanctuaryVaultNote
impl Serialize for SanctuaryVaultNote
impl Eq for SanctuaryVaultNote
impl StructuralPartialEq for SanctuaryVaultNote