pub struct ImportedMessage {Show 14 fields
pub id: String,
pub content: String,
pub maker: String,
pub created_unix: u64,
pub lamport: Option<u64>,
pub role: Option<String>,
pub content_hash: Option<u64>,
pub author_name: Option<String>,
pub reply_to_fragment: Option<String>,
pub source: Option<String>,
pub sub_agent_of: Option<String>,
pub agent_did: Option<String>,
pub model_id: Option<String>,
pub agent_backend: Option<String>,
}Expand description
A message parsed back from a Solid long-chat day file. Fields absent in a pure-Solid file (no qc:)
are defaulted honestly (role = User, Lamport derived from order by the caller if needed).
Fields
id: Stringcontent: Stringmaker: Stringcreated_unix: u64lamport: Option<u64>role: Option<String>content_hash: Option<u64>reply_to_fragment: Option<String>source: Option<String>sub_agent_of: Option<String>agent_did: Option<String>model_id: Option<String>agent_backend: Option<String>Implementations
Sourceimpl ImportedMessage
impl ImportedMessage
Sourcepub fn to_chat_message(&self, fallback_lamport: u64) -> ChatMessage
pub fn to_chat_message(&self, fallback_lamport: u64) -> ChatMessage
Reconstruct a native ChatMessage. fallback_lamport is used only when the file carried no
qc:lamport (a message that originated in a non-Qualia Solid client).