pub fn build_anatomy_pack(
model: AnatomyModel,
out_path: impl AsRef<Path>,
curated: Option<&[&str]>,
) -> Result<PackReport, String>Expand description
Build a curated .hmc pack for model and write it to out_path.
curated is the set of normalised base tokens to include (defaults to
CURATED_ORGAN_TOKENS when None). Blocking network I/O.