pub fn write_pwa_bundle(
target_dir: &Path,
manifest: &QappManifest,
) -> Result<Vec<String>, String>Expand description
Generate the PWA bundle for manifest and write every file under target_dir. Returns the list
of written (bundle-relative) paths. Rejects an invalid manifest and any unsafe bundle path.